@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -245,6 +245,7 @@ DSL_Error_t DSL_CPE_BND_AutobootStatusRestartWait(
 #if (DSL_CPE_LINES_PER_DEVICE == 2)
 DSL_Error_t DSL_CPE_BND_DeviceFirmwareDownload(
                DSL_CPE_BND_Context_t *pBndCtx,
+               DSL_int_t nDevice,
                DSL_FirmwareRequestType_t nFwReqType,
                DSL_PortMode_t nPortMode,
                DSL_boolean_t bMaster,
@@ -256,7 +257,7 @@ DSL_Error_t DSL_CPE_BND_DeviceFirmwareDownload(
    if (bMaster)
    {
       /* Download MASTER*/
-      nErrorCode = DSL_CPE_DownloadFirmware(pContext->fd[0], nFwReqType,
+      nErrorCode = DSL_CPE_DownloadFirmware(pContext->fd[0], nDevice, nFwReqType,
                                             nPortMode, DSL_NULL, DSL_NULL);
       if (nErrorCode != DSL_SUCCESS)
       {
@@ -269,7 +270,7 @@ DSL_Error_t DSL_CPE_BND_DeviceFirmwareDownload(
    if (bSlave)
    {
       /* Download MASTER*/
-      nErrorCode = DSL_CPE_DownloadFirmware(pContext->fd[1], nFwReqType,
+      nErrorCode = DSL_CPE_DownloadFirmware(pContext->fd[1], nDevice, nFwReqType,
                                             nPortMode, DSL_NULL, DSL_NULL);
       if (nErrorCode != DSL_SUCCESS)
       {
@@ -313,7 +314,7 @@ DSL_Error_t DSL_CPE_BND_SyncDownloadFirmware(
          {
             /* Download firmware for MASTER and SLAVE*/
             nErrorCode = DSL_CPE_BND_DeviceFirmwareDownload(
-                           pBndCtx, nFwReqType, nPortMode, DSL_TRUE, DSL_TRUE);
+                           pBndCtx, nDevice, nFwReqType, nPortMode, DSL_TRUE, DSL_TRUE);
             if (nErrorCode != DSL_SUCCESS)
             {
                return nErrorCode;
@@ -358,7 +359,7 @@ DSL_Error_t DSL_CPE_BND_SyncDownloadFirmware(
 
          /* Download firmware for MASTER and SLAVE*/
          nErrorCode = DSL_CPE_BND_DeviceFirmwareDownload(
-                        pBndCtx, nFwReqType, nPortMode, DSL_TRUE, DSL_TRUE);
+                        pBndCtx, nDevice, nFwReqType, nPortMode, DSL_TRUE, DSL_TRUE);
          if (nErrorCode != DSL_SUCCESS)
          {
             return nErrorCode;
@@ -407,7 +408,7 @@ DSL_Error_t DSL_CPE_BND_SyncDownloadFirmware(
       {
          /* Download firmware for MASTER*/
          nErrorCode = DSL_CPE_BND_DeviceFirmwareDownload(
-                        pBndCtx, nFwReqType, nPortMode, DSL_TRUE, DSL_FALSE);
+                        pBndCtx, nDevice, nFwReqType, nPortMode, DSL_TRUE, DSL_FALSE);
          if (nErrorCode != DSL_SUCCESS)
          {
             return nErrorCode;
