@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -17,7 +17,23 @@
 #include "dsl_cpe_control.h"
 #include "dsl_cpe_os.h"
 #include "dsl_cpe_cli.h"
+#ifdef LOGGING_ID
+   #include "ulogging.h"
 
+   #ifndef LOG_LEVEL
+   uint16_t LOGLEVEL = SYS_LOG_DEBUG + 1;
+   #else
+   uint16_t LOGLEVEL = LOG_LEVEL + 1;
+   #endif
+
+   #ifndef LOG_TYPE
+   uint16_t LOGTYPE = SYS_LOG_TYPE_FILE;
+   #else
+   uint16_t LOGTYPE = LOG_TYPE;
+   #endif
+#else /* LOGGING_ID */
+   #define LOGF_LOG_INFO(...)
+#endif /* LOGGING_ID */
 
 #ifdef INCLUDE_DSL_CPE_CLI_SUPPORT
 
@@ -152,13 +168,6 @@ static DSL_CLI_Context_t *CLI_List_head = DSL_NULL;
 /** indicates if the CLI already initialized */
 static DSL_boolean_t bCLI_Init = DSL_FALSE;
 
-#ifdef INCLUDE_DSL_CPE_SOAP_SUPPORT
-   extern const DSL_char_t g_sRsss[];
-   extern DSL_int_t DSL_CPE_SOAP_RemoteSoapServerSet(DSL_int_t fd,
-      DSL_char_t *command, DSL_CPE_File_t *out);
-#endif
-
-
 static const DSL_char_t g_sQuit[] =
 #ifndef DSL_CPE_DEBUG_DISABLE
    "Long Form: %s" DSL_CPE_CRLF
@@ -194,9 +203,6 @@ DSL_Error_t DSL_CPE_CLI_Init(DSL_void_t)
    {
       DSL_CPE_CLI_CMD_ADD_COMM("help", "Help", DSL_CPE_CLI_HelpPrint, DSL_NULL);
       DSL_CPE_CLI_CMD_ADD_COMM("quit", "Quit", DSL_CPE_CLI_Quit, g_sQuit);
-#ifdef INCLUDE_DSL_CPE_SOAP_SUPPORT
-      DSL_CPE_CLI_CMD_ADD_COMM("rsss", "RemoteSoapServerSet", DSL_CPE_SOAP_RemoteSoapServerSet, g_sRsss);
-#endif
       DSL_CPE_CLI_AccessCommandsRegister();
 
       bCLI_Init = DSL_TRUE;
@@ -220,6 +226,9 @@ DSL_Error_t DSL_CPE_CLI_HandleEvent(DSL_char_t *pMsg)
 {
    DSL_CLI_Context_t *pCLIList = CLI_List_head;
 
+   /* Using logging framework for event data content */
+   LOGF_LOG_INFO("%s", pMsg);
+
    while (pCLIList != DSL_NULL)
    {
       if (pCLIList->pEventCallback != DSL_NULL)
