@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -537,17 +537,6 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_AutobootUsedFirmwareGet(
       return -1;
    }
 
-#ifdef DSL_CPE_SOAP_FW_UPDATE
-   if ((pCtrlCtx->firmware.pData != DSL_NULL) && (pCtrlCtx->firmware.nSize > 0))
-   {
-      DSL_CPE_FPrintf (out,
-         DSL_CPE_RET"xdsl_firmware=<%s>" DSL_CPE_CRLF,
-         DSL_CPE_RET_VAL(ret),
-         (DSL_char_t *)DSL_CPE_SOAP_FWNAME_1);
-   }
-   else
-   {
-#endif /* DSL_CPE_SOAP_FW_UPDATE */
 #if defined(INCLUDE_DSL_BONDING) && (DSL_CPE_LINES_PER_DEVICE == 2)
       DSL_CPE_FPrintf (out,
          DSL_CPE_RET"xdsl_firmware=%s xdsl_firmware2=%s" DSL_CPE_CRLF,
@@ -560,9 +549,6 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_AutobootUsedFirmwareGet(
          DSL_CPE_RET_VAL(ret),
          g_sFirmwareName1 != DSL_NULL ? g_sFirmwareName1 : "n/a");
 #endif
-#ifdef DSL_CPE_SOAP_FW_UPDATE
-   }
-#endif /* DSL_CPE_SOAP_FW_UPDATE */
 
    return 0;
 }
@@ -609,6 +595,8 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_AutobootLoadFirmware(
    DSL_AutobootStatus_t  AutobootStatus;
 #endif /* #if (DSL_CPE_LINES_PER_DEVICE < 2) */
 #endif /* INCLUDE_FW_REQUEST_SUPPORT*/
+   DSL_uint32_t nDevice = 0;
+   DSL_CPE_Control_Context_t *pCtrlCtx = DSL_NULL;
 
 #if defined(INCLUDE_DSL_BONDING) && (DSL_CPE_LINES_PER_DEVICE == 2)
    if (DSL_CPE_CLI_CheckParamNumber(pCommands, 2, DSL_CLI_EQUALS) == DSL_FALSE)
@@ -677,6 +665,17 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_AutobootLoadFirmware(
    }
 #endif
 
+   pCtrlCtx = DSL_CPE_GetGlobalContext();
+   if(pCtrlCtx == DSL_NULL)
+   {
+      DSL_CPE_FPrintf (out, sFailureReturn, DSL_CPE_RET_VAL(-1));
+
+      return -1;
+   }
+
+   DSL_CPE_Fd2DevNum(fd, &nDevice);
+   pCtrlCtx->bForceFirmwareDownload[nDevice] = DSL_TRUE;
+
 #ifdef INCLUDE_FW_REQUEST_SUPPORT
 #if (DSL_CPE_LINES_PER_DEVICE < 2)
    memset(&autobootCtrl, 0x00, sizeof(DSL_AutobootControl_t));
@@ -690,11 +689,11 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_AutobootLoadFirmware(
       return 0;
    }
 
-   if ( (AutobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_FW_WAIT) ||
-        (AutobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_STOPPED &&
-         AutobootStatus.data.nFirmwareRequestType != DSL_FW_REQUEST_NA) )
+   if ( (AutobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_FW_WAIT &&
+         AutobootStatus.data.nFirmwareRequestType != DSL_FW_REQUEST_NA) ||
+        (AutobootStatus.data.nStatus == DSL_AUTOBOOT_STATUS_STOPPED))
    {
-      ret = DSL_CPE_DownloadFirmware(fd, AutobootStatus.data.nFirmwareRequestType,
+      ret = DSL_CPE_DownloadFirmware(fd, nDevice, AutobootStatus.data.nFirmwareRequestType,
                                                    DSL_PORT_MODE_NA, pcFw, pcFw2);
 
       DSL_CPE_FPrintf (out, DSL_CPE_RET, DSL_CPE_RET_VAL(ret));
@@ -722,7 +721,7 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_AutobootLoadFirmware(
       }
    }
 #else
-   ret = DSL_CPE_DownloadFirmware(fd, DSL_FW_REQUEST_NA, pcFw, pcFw2);
+   ret = DSL_CPE_DownloadFirmware(fd, nDevice, DSL_FW_REQUEST_NA, pcFw, pcFw2);
 
    DSL_CPE_FPrintf (out, DSL_CPE_RET, DSL_CPE_RET_VAL(ret));
    if (ret < DSL_SUCCESS)
@@ -902,7 +901,7 @@ static const DSL_char_t g_sBpstg[] =
    "   DSL_PROFILE_12B = 5" DSL_CPE_CRLF
    "   DSL_PROFILE_17A = 6" DSL_CPE_CRLF
    "   DSL_PROFILE_30A = 7" DSL_CPE_CRLF
-   "   DSL_PROFILE_17B = 8" DSL_CPE_CRLF
+   "   DSL_PROFILE_35B = 8" DSL_CPE_CRLF
    DSL_CPE_CRLF "";
 #else
    "";
@@ -964,7 +963,8 @@ static const DSL_char_t g_sVig[] =
    "   unknown = -1"DSL_CPE_CRLF
    "   na = 0"DSL_CPE_CRLF
    "   pots = 1"DSL_CPE_CRLF
-   "   isdn = 2"DSL_CPE_CRLF
+   "   isdn_b = 2"DSL_CPE_CRLF
+   "   isdn_bj = 3"DSL_CPE_CRLF
    DSL_CPE_CRLF "";
 #else
    "";
@@ -1442,7 +1442,10 @@ static const DSL_char_t g_sG997upbosg[] =
    "   AELE_MODE_1 = 1" DSL_CPE_CRLF
    "   AELE_MODE_2 = 2" DSL_CPE_CRLF
    "   AELE_MODE_3 = 3" DSL_CPE_CRLF
-   "- DSL_int16_t[" _MKSTR(DSL_G997_MAX_NUMBER_OF_BANDS) "] nKlePb" DSL_CPE_CRLF
+   "- DSL_uint16_t UpboElmt" DSL_CPE_CRLF
+   "- DSL_int16_t RxThreshDs" DSL_CPE_CRLF
+   "- DSL_int16_t[" _MKSTR(DSL_G997_MAX_NUMBER_OF_BANDS) "] nKleOPb" DSL_CPE_CRLF
+   "- DSL_int16_t[" _MKSTR(DSL_G997_MAX_NUMBER_OF_BANDS) "] nKleRPb" DSL_CPE_CRLF
    DSL_CPE_CRLF "";
 #else
    "";
@@ -1472,12 +1475,17 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_G997_UsPowerBackOffStatusGet(
    }
    else
    {
-      DSL_CPE_FPrintf(out, DSL_CPE_RET"nAeleMode=%u ",
-         DSL_CPE_RET_VAL(pData.accessCtl.nReturn), pData.data.nAeleMode);
+      DSL_CPE_FPrintf(out, DSL_CPE_RET"nAeleMode=%u UpboElmt=%u RxThreshDs=%d ",
+         DSL_CPE_RET_VAL(pData.accessCtl.nReturn), pData.data.nAeleMode,
+         pData.data.UpboElmt, pData.data.RxThreshDs);
 
       for (i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; i++)
       {
-         DSL_CPE_FPrintf(out, "nKlePb[%d]=%hu ", i, pData.data.nKl0EstimOPb[i]);
+         DSL_CPE_FPrintf(out, "nKleOPb[%d]=%hu ", i, pData.data.nKl0EstimOPb[i]);
+      }
+      for (i = 0; i < DSL_G997_MAX_NUMBER_OF_BANDS; i++)
+      {
+         DSL_CPE_FPrintf(out, "nKleRPb[%d]=%hu ", i, pData.data.nKl0EstimRPb[i]);
       }
 
       DSL_CPE_FPrintf(out, DSL_CPE_CRLF );
@@ -1596,6 +1604,73 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_G997_LowPowerModeConfigGet(
 }
 #endif /*INCLUDE_DSL_CONFIG_GET*/
 
+#ifdef INCLUDE_DSL_G997_STATUS
+static const DSL_char_t g_sG997ansg[] =
+#ifndef DSL_CPE_DEBUG_DISABLE
+   "Long Form: %s" DSL_CPE_CRLF
+   "Short Form: %s" DSL_CPE_CRLF
+   DSL_CPE_CRLF
+   "Input Parameter" DSL_CPE_CRLF
+#if (DSL_CPE_MAX_DSL_ENTITIES > 1)
+   "- DSL_uint32_t nDevice (optional, not used in the 'backward compatible' mode)" DSL_CPE_CRLF
+#endif
+   "- DSL_AccessDir_t nDirection" DSL_CPE_CRLF
+   "   upstream = 0" DSL_CPE_CRLF
+   "   downstream = 1" DSL_CPE_CRLF
+   DSL_CPE_CRLF
+   "Output Parameter" DSL_CPE_CRLF
+   "- DSL_Error_t nReturn" DSL_CPE_CRLF
+#if (DSL_CPE_MAX_DSL_ENTITIES > 1)
+   "- DSL_uint32_t nDevice (optional, not used in the 'backward compatible' mode)" DSL_CPE_CRLF
+#endif
+   "- DSL_AccessDir_t nDirection" DSL_CPE_CRLF
+   "   upstream = 0" DSL_CPE_CRLF
+   "   downstream = 1" DSL_CPE_CRLF
+   "- DSL_uint16_t nAttndrActMethod" DSL_CPE_CRLF
+   "- DSL_uint16_t nAttndrActInpDs" DSL_CPE_CRLF
+   "- DSL_uint16_t nAttndrActInpReinDs" DSL_CPE_CRLF
+   "- DSL_uint16_t nAttndrActDelayDs" DSL_CPE_CRLF
+   DSL_CPE_CRLF "";
+#else
+   "";
+#endif
+
+DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_G997_AttainableNdrStatusGet(
+   DSL_int_t fd,
+   DSL_char_t *pCommands,
+   DSL_CPE_File_t *out)
+{
+   DSL_int_t ret = 0;
+   DSL_G997_AttainableNdrStatus_t pData;
+
+   if (DSL_CPE_CLI_CheckParamNumber(pCommands, 1, DSL_CLI_EQUALS) == DSL_FALSE)
+   {
+      return -1;
+   }
+
+   memset(&pData, 0x0, sizeof(DSL_G997_AttainableNdrStatus_t));
+
+   DSL_CPE_sscanf (pCommands, "%u", &pData.nDirection);
+
+   ret = DSL_CPE_Ioctl (fd, DSL_FIO_G997_ATTAINABLE_NDR_STATUS_GET, (int) &pData);
+
+   if ((ret < 0) && (pData.accessCtl.nReturn < DSL_SUCCESS))
+   {
+      DSL_CPE_FPrintf (out, sFailureReturn, DSL_CPE_RET_VAL(pData.accessCtl.nReturn));
+   }
+   else
+   {
+      DSL_CPE_FPrintf (out, DSL_CPE_RET"nDirection=%u nAttndrActMethod=%d "
+         "nAttndrActInpDs=%d nAttndrActInpReinDs=%d nAttndrActDelayDs=%d"
+         DSL_CPE_CRLF, DSL_CPE_RET_VAL(pData.accessCtl.nReturn),
+         pData.nDirection, pData.data.nAttndrActMethod, pData.data.nAttndrActInpDs,
+         pData.data.nAttndrActInpReinDs, pData.data.nAttndrActDelayDs);
+   }
+
+   return 0;
+}
+#endif /* INCLUDE_DSL_G997_STATUS*/
+
 #ifdef INCLUDE_DSL_CONFIG_GET
 static const DSL_char_t g_sDsmcg[] =
 #ifndef DSL_CPE_DEBUG_DISABLE
@@ -2512,6 +2587,7 @@ static const DSL_char_t g_sVpcs[] =
    "   DSL_BF_PROFILE_12B = 0x00000020" DSL_CPE_CRLF
    "   DSL_BF_PROFILE_17A = 0x00000040" DSL_CPE_CRLF
    "   DSL_BF_PROFILE_30A = 0x00000080" DSL_CPE_CRLF
+   "   DSL_BF_PROFILE_35B = 0x00000100" DSL_CPE_CRLF
    DSL_CPE_CRLF
    "Output Parameter" DSL_CPE_CRLF
    "- DSL_Error_t nReturn" DSL_CPE_CRLF
@@ -2579,6 +2655,7 @@ static const DSL_char_t g_sVpcg[] =
    "   DSL_BF_PROFILE_12B = 0x00000020" DSL_CPE_CRLF
    "   DSL_BF_PROFILE_17A = 0x00000040" DSL_CPE_CRLF
    "   DSL_BF_PROFILE_30A = 0x00000080" DSL_CPE_CRLF
+   "   DSL_BF_PROFILE_35B = 0x00000100" DSL_CPE_CRLF
    DSL_CPE_CRLF "";
 #else
    "";
@@ -2754,6 +2831,68 @@ DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_MEI_PllOffsetConfigSet(
    return 0;
 }
 
+static const DSL_char_t g_sRaSg[] =
+#ifndef DSL_CPE_DEBUG_DISABLE
+   "Long Form: %s" DSL_CPE_CRLF
+   "Short Form: %s" DSL_CPE_CRLF
+   DSL_CPE_CRLF
+   "Input Parameter" DSL_CPE_CRLF
+#if (DSL_CPE_MAX_DEVICE_NUMBER > 1)
+   "- DSL_uint32_t nDevice (optional, not used in the 'backward compatible' mode)" DSL_CPE_CRLF
+#endif
+   "- DSL_AccessDir_t nDirection" DSL_CPE_CRLF
+   "   upstream = 0" DSL_CPE_CRLF
+   "   downstream = 1" DSL_CPE_CRLF
+   DSL_CPE_CRLF
+   "Output Parameter" DSL_CPE_CRLF
+   "- DSL_Error_t nReturn" DSL_CPE_CRLF
+#if (DSL_CPE_MAX_DEVICE_NUMBER > 1)
+   "- DSL_uint32_t nDevice (optional, not used in the 'backward compatible' mode)" DSL_CPE_CRLF
+#endif
+   "- DSL_uint8_t nDirection" DSL_CPE_CRLF
+   "- DSL_G997_RA_MODE_t RA_MODE" DSL_CPE_CRLF
+   "   manual      = 1" DSL_CPE_CRLF
+   "   at init     = 2" DSL_CPE_CRLF
+   "   dynamic     = 3" DSL_CPE_CRLF
+   "   dynamic SOS = 4" DSL_CPE_CRLF
+   DSL_CPE_CRLF "";
+#else
+   "";
+#endif
+
+DSL_CLI_LOCAL DSL_int_t DSL_CPE_CLI_G997_RateAdaptationStatusGet(
+   DSL_int_t fd,
+   DSL_char_t *pCommands,
+   DSL_CPE_File_t *out)
+{
+   DSL_int_t ret = 0;
+   DSL_G997_RateAdaptationStatus_t pData;
+
+   if (DSL_CPE_CLI_CheckParamNumber(pCommands, 1, DSL_CLI_EQUALS) == DSL_FALSE)
+   {
+      return -1;
+   }
+
+   memset(&pData, 0x0, sizeof(DSL_G997_RateAdaptationStatus_t));
+
+   DSL_CPE_sscanf (pCommands, "%u", &pData.nDirection);
+
+   ret = DSL_CPE_Ioctl (fd, DSL_FIO_G997_RATE_ADAPTATION_STATUS_GET, (int) &pData);
+
+   if ((ret < 0) && (pData.accessCtl.nReturn < DSL_SUCCESS))
+   {
+      DSL_CPE_FPrintf (out, sFailureReturn, DSL_CPE_RET_VAL(pData.accessCtl.nReturn));
+   }
+   else
+   {
+      DSL_CPE_FPrintf (out, DSL_CPE_RET"nDirection=%hu RA_MODE=%u" DSL_CPE_CRLF,
+         DSL_CPE_RET_VAL(pData.accessCtl.nReturn),
+         pData.nDirection, pData.data.RA_MODE);
+   }
+
+   return 0;
+}
+
 DSL_void_t DSL_CPE_CLI_DeviceCommandsRegister (DSL_void_t)
 {
    /* Debug functionalities */
@@ -2784,6 +2923,10 @@ DSL_void_t DSL_CPE_CLI_DeviceCommandsRegister (DSL_void_t)
    DSL_CPE_CLI_CMD_ADD_COMM ("g997lpmcg", "G997_LowPowerModeConfigGet", DSL_CPE_CLI_G997_LowPowerModeConfigGet, g_sLpmcg);
 #endif /* #ifdef INCLUDE_DSL_CONFIG_GET*/
 
+#ifdef INCLUDE_DSL_G997_STATUS
+   DSL_CPE_CLI_CMD_ADD_COMM ("g997ansg", "G997_AttainableNdrStatusGet", DSL_CPE_CLI_G997_AttainableNdrStatusGet, g_sG997ansg);
+#endif /* #ifdef INCLUDE_DSL_G997_STATUS*/
+
 #ifdef INCLUDE_DSL_CONFIG_GET
    DSL_CPE_CLI_CMD_ADD_COMM ("dsmcg", "DSM_ConfigGet", DSL_CPE_CLI_DsmConfigGet, g_sDsmcg);
 #endif /* INCLUDE_DSL_CONFIG_GET*/
@@ -2819,6 +2962,8 @@ DSL_void_t DSL_CPE_CLI_DeviceCommandsRegister (DSL_void_t)
    DSL_CPE_CLI_CMD_ADD_COMM ("meipocg", "MEI_PllOffsetConfigGet", DSL_CPE_CLI_MEI_PllOffsetConfigGet, g_sMEIPocg);
 #endif /* INCLUDE_DSL_CONFIG_GET*/
    DSL_CPE_CLI_CMD_ADD_COMM ("meipocs", "MEI_PllOffsetConfigSet", DSL_CPE_CLI_MEI_PllOffsetConfigSet, g_sMEIPocs);
+
+   DSL_CPE_CLI_CMD_ADD_COMM ("g997rasg", "G997_RateAdaptationStatusGet", DSL_CPE_CLI_G997_RateAdaptationStatusGet, g_sRaSg);
 }
 
 #endif /* INCLUDE_DSL_CPE_CLI_SUPPORT */
