@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -11,7 +11,7 @@
 #ifndef _DSL_CPE_CONTROL_H
 #define _DSL_CPE_CONTROL_H
 
-/** \defgroup DSL_CPE_CONTROL Lantiq DSL CPE API Control Application
+/** \defgroup DSL_CPE_CONTROL Intel DSL CPE API Control Application
     Lists the entire modules to the DSL CPE_API Control Application.
   @{ */
 
@@ -69,7 +69,7 @@ system support enabled only"
 #if defined(DSL_DEBUG_TOOL_INTERFACE) || defined(INCLUDE_DSL_CPE_DTI_SUPPORT)
 #ifdef LINUX
    #define DSL_DEBUG_TOOL_INTERFACE_DEFAULT_IFACE "eth0"
-#elif VXWORKS
+#elif defined(VXWORKS)
    #define DSL_DEBUG_TOOL_INTERFACE_DEFAULT_IFACE "ei0"
 #else
    #error "OS type undefined!"
@@ -150,29 +150,16 @@ system support enabled only"
 /*
    Security checks for configure options
 */
-#ifdef INCLUDE_DSL_CPE_SOAP_SUPPORT
-   #ifndef INCLUDE_DSL_CPE_CLI_SUPPORT
-      #error "SOAP support requires CLI please define 'INCLUDE_DSL_CPE_CLI_SUPPORT'"
-   #endif
-#endif /* INCLUDE_DSL_CPE_SOAP_SUPPORT */
-
 #if defined(INCLUDE_DSL_CPE_DTI_SUPPORT) && defined(INCLUDE_DSL_CPE_API_DANUBE)
    #ifndef INCLUDE_DSL_CPE_CLI_SUPPORT
       #error "DTI support for Danube requires CLI please define 'INCLUDE_DSL_CPE_CLI_SUPPORT'"
    #endif
 #endif /* INCLUDE_DSL_CPE_DTI_SUPPORT */
 
-#if !defined (INCLUDE_DSL_CPE_SOAP_SUPPORT) && !defined(INCLUDE_DSL_CPE_CLI_SUPPORT)
+#if !defined(INCLUDE_DSL_CPE_CLI_SUPPORT)
 #define DSL_CPE_REMOVE_PIPE_SUPPORT
 #endif
 
-
-#ifdef INCLUDE_DSL_CPE_SOAP_SUPPORT
-#define DSL_CPE_SOAP_PORT           8080
-   /* Enable firmware update functionality in case of SOAP support by default */
-   #define DSL_CPE_SOAP_FW_UPDATE
-#endif /* INCLUDE_DSL_CPE_SOAP_SUPPORT */
-
 extern DSL_boolean_t g_bWaitBeforeLinkActivation[DSL_CPE_MAX_DSL_ENTITIES];
 extern DSL_boolean_t g_bWaitBeforeConfigWrite[DSL_CPE_MAX_DSL_ENTITIES];
 extern DSL_boolean_t g_bWaitBeforeRestart[DSL_CPE_MAX_DSL_ENTITIES];
@@ -332,8 +319,7 @@ typedef struct
    /*
    File name is only used in case of using firmware binary that is located
    within file system. If firmware that is used which is already stored
-   within context of DSL CPE Control Application (for example in case of
-   using SOAP firmware download function) this pointer shall be DSL_NULL. */
+   within context of DSL CPE Control Applicationthis pointer shall be DSL_NULL.*/
    DSL_char_t *pFileName;
    /*
    Pointer to firmware binary in case of using data stored within context of
@@ -366,18 +352,6 @@ typedef struct
    DSL_void_t *pDebugCliClientInfo;
 #endif /* INCLUDE_DSL_CPE_CLI_SUPPORT*/
 #endif /* DSL_DEBUG_TOOL_INTERFACE*/
-#ifdef DSL_CPE_SOAP_FW_UPDATE
-   #define DSL_CPE_SOAP_FWNAME_1    "SoapFwName1"
-   #define DSL_CPE_SOAP_FWNAME_2    "SoapFwName2"
-   /* Semaphore used in case of updating the firmware binar(y/ies) via SOAP */
-   DSL_CPE_Lock_t semFwUpdate;
-   /*
-   Specifies an firmware that might be updated using SOAP */
-   DSL_CPE_Firmware_t firmware;
-   /*
-   Specifies an firmware that might be updated using SOAP */
-   DSL_CPE_Firmware_t firmware2;
-#endif /* DSL_CPE_SOAP_FW_UPDATE */
 
 #ifdef INCLUDE_DSL_CPE_CLI_SUPPORT
    DSL_CLI_Context_t *pCLI_List_head;
@@ -393,6 +367,7 @@ typedef struct
 #ifdef INCLUDE_DSL_BONDING
    DSL_void_t *pBnd;
 #endif /* INCLUDE_DSL_BONDING*/
+   DSL_boolean_t bForceFirmwareDownload[DSL_CPE_MAX_DSL_ENTITIES];
 } DSL_CPE_Control_Context_t;
 
 #include "dsl_cpe_debug.h"
@@ -420,6 +395,21 @@ typedef enum
 } DSL_CPE_ScriptSection_t;
 #endif /* #ifdef INCLUDE_DSL_CPE_CMV_SCRIPTS_SUPPORT*/
 
+#define MAX_SCRIPT_CMD_LEN 1024
+
+/**
+   Structure for dynamic script buffers.
+*/
+typedef struct
+{
+   /** dynamic buffer */
+   DSL_char_t *buffer_cmd;
+   /** dynamic buffer */
+   DSL_char_t *buffer_tmp;
+   /** buffer size */
+   DSL_int_t nSize;
+} DSL_CPE_ScriptBuffer_t;
+
 /**
    Structure for parsing startup arguments.
 */
@@ -460,6 +450,7 @@ DSL_Error_t DSL_CPE_LoadFirmwareFromFile
 DSL_Error_t DSL_CPE_DownloadFirmware
 (
    DSL_int_t fd,
+   DSL_int_t nDevice,
    DSL_FirmwareRequestType_t nFwReqType,
    DSL_PortMode_t nPortMode,
    DSL_char_t *pcFw,
@@ -478,7 +469,9 @@ typedef enum
    /* Format as hey values */
    DSL_ARRAY_FORMAT_HEX,
    /* Format as string */
-   DSL_ARRAY_FORMAT_STRING
+   DSL_ARRAY_FORMAT_STRING,
+   /* Format as string (print dots instead of non print symbols) */
+   DSL_ARRAY_FORMAT_PRINT_STRING
 } DSL_CPE_ArrayPrintFormat_t;
 
 DSL_void_t DSL_CPE_ArraySPrintF
@@ -526,30 +519,6 @@ DSL_Error_t DSL_CPE_GetMacAdrFromString
 #endif /* defined(INCLUDE_DSL_CPE_API_VRX) */
 #endif /* INCLUDE_DSL_CPE_CLI_SUPPORT */
 
-/*
-   some declarations for modules without own header
-*/
-#ifdef INCLUDE_DSL_CPE_SOAP_SUPPORT
-   DSL_int32_t DSL_CPE_SoapInit(DSL_CPE_Control_Context_t *pContext);
-   DSL_int32_t DSL_CPE_SoapExit(DSL_void_t);
-
-   #ifdef DSL_CPE_SOAP_FW_UPDATE
-      DSL_Error_t DSL_CPE_SoapFirmwareUpdate
-      (
-         DSL_CPE_Firmware_t *pFirmware,
-         DSL_CPE_Firmware_t *pFirmware2
-      );
-
-      DSL_Error_t DSL_CPE_SoapFirmwareStore
-      (
-         DSL_CPE_Control_Context_t *pContext,
-         DSL_CPE_Firmware_t *pSrcFirmware,
-         DSL_CPE_Firmware_t *pDestFirmware,
-         DSL_char_t *pFwSoapName
-      );
-   #endif /* DSL_CPE_SOAP_FW_UPDATE */
-#endif /* INCLUDE_DSL_CPE_SOAP_SUPPORT */
-
 /*
    Start Event handler thread
 */
@@ -568,7 +537,8 @@ DSL_Error_t DSL_CPE_ScriptExecute
    DSL_CPE_Control_Context_t * pContext,
    DSL_int_t nDevice,
    DSL_CPE_File_t *pFile,
-   DSL_CPE_ScriptSection_t searchSection
+   DSL_CPE_ScriptSection_t searchSection,
+   DSL_CPE_ScriptBuffer_t *script_buf
 );
 
 DSL_Error_t DSL_CPE_ScriptFileParse
