@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -20,15 +20,17 @@ Includes
 
 #ifndef DSL_CPE_DEBUG_DISABLE
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+DSL_CCA_debugDestinations_t DSL_CCA_g_dbgDestination = DSL_CCA_DBG_DST_CONSOLE;
+#endif /* INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT */
+
 /* Default initialization for all debug blocks */
-DSL_CCA_debugLevelEntry_t DSL_CCA_g_dbgLvl[DSL_CCA_DBG_MAX_ENTRIES] =
-{
+DSL_CCA_debugLevelEntry_t DSL_CCA_g_dbgLvl[DSL_CCA_DBG_MAX_ENTRIES] =   {
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_NO_BLOCK"       },   /* 00 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_APP"            },   /* 01 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_OS"             },   /* 02 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_CLI"            },   /* 03 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_PIPE"           },   /* 04 */
-   { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_SOAP"           },   /* 05 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_CONSOLE"        },   /* 06 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_TCPMSG"         },   /* 07 */
    { DSL_CCA_DBG_NONE,   "DSL_CCA_DBG_MULTIMODE"      },   /* 08 */
