@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -67,8 +67,6 @@ typedef enum
    DSL_CCA_DBG_CLI = 3,
    /** Pipe specific block */
    DSL_CCA_DBG_PIPE = 4,
-   /** SOAP specific block */
-   DSL_CCA_DBG_SOAP = 5,
    /** Console specific block */
    DSL_CCA_DBG_CONSOLE = 6,
    /** TCP Message specific block */
@@ -97,6 +95,19 @@ typedef struct
    DSL_char_t *pcName;
 } DSL_CCA_debugLevelEntry_t;
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+/** 
+   Definitions for defining the debug destination.
+*/
+typedef enum
+{
+   /** output will be passed to the console */
+   DSL_CCA_DBG_DST_CONSOLE = 0x00,
+   /** output will be passed to the logger application */
+   DSL_CCA_DBG_DST_LOGGER  = 0x01
+} DSL_CCA_debugDestinations_t;
+#endif /* INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT */
+
 #define  DSL_CCA_DBG_MAX_PRINT_CHAR  256
 
 #undef DSL_CCA_DBG_PRINTF
@@ -212,6 +223,9 @@ typedef struct
 
 extern DSL_CCA_debugLevelEntry_t DSL_CCA_g_dbgLvl[DSL_CCA_DBG_MAX_ENTRIES];
 extern DSL_CCA_debugLevels_t DSL_CCA_g_globalDbgLvl;
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+extern DSL_CCA_debugDestinations_t DSL_CCA_g_dbgDestination;
+#endif /* INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT */
 #ifndef _lint
 extern DSL_CCA_debugLevelEntry_t DSL_CCA_g_dbgLvlNames[];
 extern const DSL_uint8_t DSL_CCA_g_dbgLvlNumber;
