@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -95,8 +95,8 @@ DSL_void_t N2H_SwapCmvPaylDWord(CMV_MESSAGE_ALL_T *pCmvMsg, DSL_int_t startIdx,
 
    for (i=startIdx; i < (startIdx + count_32bit); i++)
    {
-      pCmvMsg->cmv.payload.params_32Bit[i] =
-                  N2H_SWAP_CMV_PAYL_32v16(pCmvMsg->cmv.payload.params_32Bit[i]);
+      ((unsigned int *)pCmvMsg->rawMsg)[i] =
+                 N2H_SWAP_CMV_PAYL_32v16(((unsigned int *)pCmvMsg->rawMsg)[i]);
    }
    return;
 }
@@ -110,8 +110,8 @@ DSL_void_t H2N_SwapCmvPaylDWord(CMV_MESSAGE_ALL_T *pCmvMsg, DSL_int_t startIdx,
    DSL_int_t i;
    for (i=startIdx; i < (startIdx + count_32bit); i++)
    {
-      pCmvMsg->cmv.payload.params_32Bit[i] =
-                  H2N_SWAP_CMV_PAYL_32v16(pCmvMsg->cmv.payload.params_32Bit[i]);
+      ((unsigned int *)pCmvMsg->rawMsg)[i] =
+                 H2N_SWAP_CMV_PAYL_32v16(((unsigned int *)pCmvMsg->rawMsg)[i]);
    }
    return;
 }
@@ -336,10 +336,8 @@ DSL_int_t DSL_CPE_VRX_Reboot(
    DSL_int_t nRet = 0;
    DSL_char_t *pcFw = DSL_NULL, *pcFw2 = DSL_NULL;
    DSL_AutobootLoadFirmware_t ldFw;
-#if (DSL_CPE_LINES_PER_DEVICE < 2)
    DSL_AutobootControl_t autobootCtrl;
    DSL_AutobootStatus_t  autobootStatus;
-#endif
 #ifdef INCLUDE_SMS00976338
    DSL_AutobootConfig_t pAcfg;
 #endif /* #ifdef INCLUDE_SMS00976338*/
@@ -1227,11 +1225,10 @@ static DSL_int_t DSL_CPE_VRX_TcpMsgSend(
    {
       case CMV_MSG_BIT_SIZE_8BIT:
       case CMV_MSG_BIT_SIZE_16BIT:
-         /*H2N_SWAP_CMV_BLOCK_WORD(pCmvMsg, CMV_HEADER_16BIT_SIZE, (CMVSizeByte >> 1));*/
          H2N_SWAP_CMV_BLOCK_WORD(pCmvMsg, CMV_HEADER_16BIT_SIZE, (CMVSizeByte >> 1)-CMV_HEADER_16BIT_SIZE);
          break;
       case CMV_MSG_BIT_SIZE_32BIT:
-         H2N_SWAP_CMV_PAYL_DWORD(pCmvMsg, 0, (CMVSizeByte >> 2));
+         H2N_SWAP_CMV_PAYL_DWORD(pCmvMsg, CMV_HEADER_32BIT_SIZE, (CMVSizeByte >> 2)-CMV_HEADER_32BIT_SIZE);
          break;
       default:
          DSL_CCA_DEBUG (DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
@@ -1594,7 +1591,7 @@ DSL_int_t DSL_CPE_DEV_TcpMessageHandle(
             N2H_SWAP_CMV_BLOCK_WORD(pRecvCmvMsg, CMV_HEADER_16BIT_SIZE, PayloadSize);
             break;
          case CMV_MSG_BIT_SIZE_32BIT:
-            N2H_SWAP_CMV_PAYL_DWORD(pRecvCmvMsg, 0, (PayloadSize >> 1));
+            N2H_SWAP_CMV_PAYL_DWORD(pRecvCmvMsg, CMV_HEADER_32BIT_SIZE, (PayloadSize >> 1));
             break;
          default:
             DSL_CCA_DEBUG (DSL_CCA_DBG_ERR, (DSL_CPE_PREFIX
