@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -39,6 +39,25 @@
 #define DTI_STATIC   static
 #endif
 
+#if (DTI_AGENT_VER_MAJOR >= 1)
+/*
+   Note: With the DTI Version >= 1.0.0 the following changes have been made:
+         - Build process:
+            use dynamic libraries
+         - Device handling:
+            allow several devices in parallel
+            separate device handling (device part will be in a own library)
+         - Interface:
+            New interface to start and register several devices.
+*/
+#  define DTI_INTERFACE_VERSION        1
+#else
+#  define DTI_INTERFACE_VERSION        0
+#endif 
+
+#if defined(INCLUDE_DSL_CPE_API_VRX) && (DTI_INTERFACE_VERSION > 0)
+extern DTI_DeviceAccessFct_t DTI_DeviceAccessFct_VRX;
+#endif 
 
 /* ============================================================================
    Local defines
@@ -61,6 +80,7 @@ struct DSL_CPE_Dti_Context_s
 
 typedef struct DSL_CPE_Dti_Context_s DSL_CPE_Dti_Context_t;
 
+
 /* ============================================================================
    Local Function declarations
    ========================================================================= */
@@ -110,6 +130,7 @@ DTI_STATIC DSL_int_t DSL_CPE_CLI_Dti_Command_Exec(
 
    /* get command name */
    sscanf(pCliDtiCommand, "%255s", cmdBuf);
+   cmdBuf[255] = '\0';
 
    if(strlen(cmdBuf) < strlen(pCliDtiCommand))
    {
@@ -240,6 +261,12 @@ DTI_STATIC DSL_int_t DSL_CPE_CLI_Dti_Exec(
    */
    retVal = DSL_CPE_CLI_Dti_Command_Exec(pCliDtiContext, pCmdIn, pOutStream);
 
+
+   if (retVal)
+   {
+      DSL_CPE_FPrintf(DSL_CPE_STDOUT, DSL_CPE_PREFIX"nReturn=%d" DSL_CPE_CRLF, retVal);
+   }
+
 #if defined(IFXOS_HAVE_MEMORY_FILE) && (IFXOS_HAVE_MEMORY_FILE == 1)
    DSL_CPE_FClose(pOutStream);
 
@@ -278,6 +305,77 @@ DSL_Error_t DSL_CPE_Dti_Start(
 
    memset(&dtiStartup, 0x00, sizeof(DTI_AgentStartupSettings_t));
 
+#if defined(INCLUDE_DSL_CPE_API_VRX) && (DTI_INTERFACE_VERSION > 0)
+   DTI_AgentStartupSettingsXDevs_t  AgentStartupSettingsXDevs;
+   DTI_DeviceAccessFct_t            *pDeviceAccessFct = IFX_NULL;
+
+   if (DSL_CPE_GlobalDtiContext.bEnabled == DSL_TRUE)
+   {
+      /* already running */
+      return DSL_SUCCESS;
+   }
+
+   /* init the DTI control struct */
+   memset(&DSL_CPE_GlobalDtiContext, 0, sizeof(DSL_CPE_Dti_Context_t));
+   DSL_CPE_GlobalDtiContext.ifNum = -1;
+
+   if (DSL_CPE_GlobalDtiContext.pDtiAgent == DSL_NULL)
+   {
+      memset(&AgentStartupSettingsXDevs, 0x00, sizeof(DTI_AgentStartupSettingsXDevs_t));
+
+      /* DTI Agent configuration */
+      AgentStartupSettingsXDevs.debugLevel                = 3;
+      AgentStartupSettingsXDevs.bStartupAutoCliMsgSupport = (bEnableCliAutoMsg == DSL_TRUE) ? 1 : 0;
+
+#if defined(DTI_SUPPORT_SINGLE_THREADED_MODE) && (DTI_SUPPORT_SINGLE_THREADED_MODE == 1)
+      /*
+         Out from the DTI Agent interface:
+            This version ot the DTI Agent supports "single threaded mode"
+      */
+      if (bEnableSingleThreadMode == DSL_TRUE)
+      {
+         AgentStartupSettingsXDevs.bSingleThreadedMode = 1;
+         AgentStartupSettingsXDevs.numOfUsedWorker     = 1;
+      }
+      else
+      {
+         AgentStartupSettingsXDevs.bSingleThreadedMode = 0;
+         AgentStartupSettingsXDevs.numOfUsedWorker     = 4;
+      }
+#endif
+
+      /* DTI IP Setup setup */
+      strncpy(AgentStartupSettingsXDevs.serverIpAddr, pDtiServerIp, 16);
+      AgentStartupSettingsXDevs.listenPort = (dtiListenPort == 0) ? 9000 : (IFX_uint16_t)dtiListenPort;
+
+      pDeviceAccessFct = &DTI_DeviceAccessFct_VRX;
+
+      if ( (pDeviceAccessFct != IFX_NULL) &&
+           (numOfPhyDevices > 0) && (numOfLinesPerPhyDevice > 0) )
+      {
+         AgentStartupSettingsXDevs.devIfSettings[0].bStartupAutoDevMsgSupport =
+                                                   (bEnableDevAutoMsg == DSL_TRUE) ? 1 : 0;
+         AgentStartupSettingsXDevs.devIfSettings[0].numOfDevices     = (IFX_int_t)numOfPhyDevices;
+         AgentStartupSettingsXDevs.devIfSettings[0].linesPerDevice   = (IFX_int_t)numOfLinesPerPhyDevice;
+         AgentStartupSettingsXDevs.devIfSettings[0].pDeviceAccessFct = pDeviceAccessFct;
+      }
+
+      /*
+         start the DTI Agent
+      */
+      if ( DTI_AgentStartXDevs(&pDtiAgent, &AgentStartupSettingsXDevs) != DTI_SUCCESS)
+      {
+         DSL_CPE_FPrintf(DSL_CPE_STDOUT, DSL_CPE_PREFIX "DSL: ERROR - start DTI agent (several devices)" DSL_CPE_CRLF);
+
+         return DSL_ERROR;
+      }
+      DSL_CPE_GlobalDtiContext.pDtiAgent = pDtiAgent;
+   }
+   else
+   {
+      DSL_CPE_FPrintf(DSL_CPE_STDOUT, DSL_CPE_PREFIX "DSL: WARNING - DTI agent already running" DSL_CPE_CRLF);
+   }
+#else /* defined(INCLUDE_DSL_CPE_API_VRX) && (DTI_INTERFACE_VERSION > 0) */
    if (DSL_CPE_GlobalDtiContext.pDtiAgent == DSL_NULL)
    {
       /* init the DTI control struct */
@@ -331,6 +429,7 @@ DSL_Error_t DSL_CPE_Dti_Start(
    {
       DSL_CPE_FPrintf(DSL_CPE_STDOUT, DSL_CPE_PREFIX"WARNING - DTI agent already running" DSL_CPE_CRLF);
    }
+#endif/* defined(INCLUDE_DSL_CPE_API_VRX) && (DTI_INTERFACE_VERSION > 0) */
 
 #if defined(INCLUDE_DSL_CPE_CLI_SUPPORT)
    if (DSL_CPE_GlobalDtiContext.bEnabled != DSL_TRUE)
