@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -19,6 +19,13 @@
 #include "dsl_cpe_control.h"
 #include "dsl_cpe_os.h"
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+#include "drv_dsl_cpe_debug.h"
+#include <sys/types.h>
+#include <sys/socket.h>
+#include <linux/netlink.h>
+#endif
+
 #ifndef INCLUDE_DSL_CPE_IFXOS_SUPPORT
 
 #ifndef PRJ_NAME_PREFIX
@@ -38,6 +45,14 @@ static struct termios stored_stdin_settings;
 static struct termios stored_stdout_settings;
 #endif /* INCLUDE_DSL_CPE_IFXOS_SUPPORT*/
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+#define NETLINK_DBG_MSG              28
+#define NL_DBG_MSG_GROUP             1
+#define MAX_MSG_SIZE_BYTES           256
+
+static void DSL_CPE_NlSendMsg(DSL_char_t* pMsg);
+#endif
+
 #ifndef INCLUDE_DSL_CPE_IFXOS_SUPPORT
 /**
    For a detailed description of the function, its arguments and return value
@@ -559,7 +574,7 @@ DSL_CPE_File_t *DSL_CPE_FOpen(const DSL_char_t *name,  const DSL_char_t *mode)
    return fopen(name, mode);
 }
 
-#if defined(INCLUDE_DSL_CPE_DTI_SUPPORT)||defined(INCLUDE_DSL_CPE_SOAP_SUPPORT)
+#if defined(INCLUDE_DSL_CPE_DTI_SUPPORT)
 /**
    For a detailed description of the function, its arguments and return value
    please refer to the description in the header file 'dsl_cpe_os.h'
@@ -568,7 +583,7 @@ DSL_CPE_File_t *DSL_CPE_FMemOpen (DSL_char_t *buf, const DSL_uint32_t size, cons
 {
    return fmemopen(buf, size, mode);
 }
-#endif /* INCLUDE_DSL_CPE_DTI_SUPPORT || INCLUDE_DSL_CPE_SOAP_SUPPORT */
+#endif /* INCLUDE_DSL_CPE_DTI_SUPPORT */
 
 /**
    For a detailed description of the function, its arguments and return value
@@ -1444,16 +1459,89 @@ int DSL_CPE_debug_printf(DSL_char_t *fmt, ...)
 {
    va_list ap;   /* points to each unnamed arg in turn */
    DSL_int_t nRet = 0;
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+#ifndef DSL_CPE_DEBUG_DISABLE
+   IFX_char_t debugString[MAX_MSG_SIZE_BYTES + 1] = {0};
 
+   /* add the debug string itself */
    va_start(ap, fmt);   /* set ap pointer to 1st unnamed arg */
-
-   nRet = vprintf(fmt, ap);
-
+   nRet = vsnprintf(&debugString[0], DSL_DBG_MAX_DEBUG_PRINT_CHAR, fmt, ap);
    va_end(ap);
 
+   if (DSL_CCA_g_dbgDestination == DSL_CCA_DBG_DST_CONSOLE)
+   {
+      printf(debugString);
+   }
+   else
+   {
+      /* send the formed string to the logger */
+      DSL_CPE_NlSendMsg(debugString);
+   }
+#endif /* DSL_CPE_DEBUG_DISABLE */
+#else
+   va_start(ap, fmt);   /* set ap pointer to 1st unnamed arg */
+   nRet = vprintf(fmt, ap);
+   va_end(ap);
+#endif   
+
    return nRet;
 }
 
+#ifdef INCLUDE_DSL_CPE_DEBUG_LOGGER_SUPPORT
+static void DSL_CPE_NlSendMsg(DSL_char_t* pMsg)
+{
+   DSL_int_t nSockFd = -1;
+   struct sockaddr_nl srcAddr, dstAddr;
+   struct nlmsghdr *pNlMsgHdr;
+   struct msghdr msg;
+   struct iovec iov;
+
+   nSockFd = socket(AF_NETLINK, SOCK_RAW, NETLINK_DBG_MSG);
+   if(nSockFd == -1) 
+   {
+      printf("could not open netlink socket");
+      DSL_CCA_DEBUG(DSL_CCA_DBG_MSG, (DSL_CPE_PREFIX
+        "could not open netlink socket" DSL_CPE_CRLF));
+        
+      return;
+   }   
+
+   /* source address */
+   memset(&srcAddr, 0, sizeof(srcAddr));
+   srcAddr.nl_family = AF_NETLINK;
+   srcAddr.nl_pid = getpid();
+   srcAddr.nl_groups = NL_DBG_MSG_GROUP;
+   if (bind(nSockFd, (struct sockaddr*)&srcAddr, sizeof(srcAddr))) {
+      return;
+   }
+
+   memset(&dstAddr, 0, sizeof(dstAddr));
+   dstAddr.nl_family = AF_NETLINK;
+   dstAddr.nl_groups = NL_DBG_MSG_GROUP;
+
+   /* Fill the netlink message header and data */
+   pNlMsgHdr = (struct nlmsghdr*) malloc(NLMSG_SPACE(MAX_MSG_SIZE_BYTES));
+   memset(pNlMsgHdr, 0, NLMSG_SPACE(MAX_MSG_SIZE_BYTES));
+   pNlMsgHdr->nlmsg_len = MAX_MSG_SIZE_BYTES;
+   pNlMsgHdr->nlmsg_pid = getpid();
+   pNlMsgHdr->nlmsg_flags = 1;
+   pNlMsgHdr->nlmsg_type = 0; 
+   
+   strcpy(NLMSG_DATA(pNlMsgHdr), pMsg);   
+
+   iov.iov_base = (void*) pNlMsgHdr;
+   iov.iov_len = pNlMsgHdr->nlmsg_len;
+   msg.msg_name = (void*) &dstAddr;
+   msg.msg_namelen = sizeof(dstAddr);
+   msg.msg_iov = &iov;
+   msg.msg_iovlen = 1;
+
+   sendmsg(nSockFd, &msg, 0);
+
+   close(nSockFd);
+}
+#endif
+
 /**
    Segmentation fault handler. Will print the current thread id.
 
