@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -522,21 +522,6 @@ void DSL_CPE_Free(DSL_void_t *memblock);
 */
 DSL_CPE_File_t *DSL_CPE_FOpen(const DSL_char_t *name,  const DSL_char_t *mode);
 
-#if defined(INCLUDE_DSL_CPE_DTI_SUPPORT)||defined(INCLUDE_DSL_CPE_SOAP_SUPPORT)
-/**
-   Open a memory file. The size is limited to 32 kBytes.
-
-   \param buf     temporary buffer for for fprintf operation.
-   \param size    buffer size
-   \param mode    not used
-
-   \return
-      - pointer to FILE structure
-      - in case of error the return value is NULL
-*/
-DSL_CPE_File_t *DSL_CPE_FMemOpen(DSL_char_t *buf, const DSL_uint32_t size, const DSL_char_t *mode);
-
-#endif /* #ifdef INCLUDE_DSL_CPE_SOAP_SUPPORT */
 /**
    Close the file or memory file.
 */
