@@ -1,7 +1,7 @@
 /******************************************************************************
 
-                              Copyright (c) 2014
-                            Lantiq Deutschland GmbH
+                          Copyright (c) 2007-2015
+                     Lantiq Beteiligungs-GmbH & Co. KG
 
   For licensing information, see the file 'LICENSE' in the root folder of
   this software module.
@@ -31,15 +31,15 @@
 #ifndef _lint
 #ifdef LINUX
 #include "dsl_cpe_linux.h"
-#elif WIN32
+#elif defined(WIN32)
 #include "dsl_cpe_win32.h"
-#elif VXWORKS
+#elif defined(VXWORKS)
 #include "dsl_cpe_vxworks.h"
-#elif ECOS
+#elif defined(ECOS)
 #include "dsl_cpe_ecos.h"
-#elif RTEMS
+#elif defined(RTEMS)
 #include "dsl_cpe_rtems.h"
-#elif GENERIC_OS
+#elif defined(GENERIC_OS)
 #include "dsl_cpe_generic_os.h"
 #else
 #error please define your OS for the CPE Control adaptation
@@ -82,11 +82,6 @@
 #define DSL_CPE_CONTROL_STACK_SIZE   (4096)
 #endif
 
-/** SOAP task stack size */
-#ifndef DSL_CPE_SOAP_STACK_SIZE
-#define DSL_CPE_SOAP_STACK_SIZE      (20000)
-#endif
-
 /** Pipe task stack size */
 #ifndef DSL_CPE_PIPE_STACK_SIZE
 #define DSL_CPE_PIPE_STACK_SIZE      (8192)
